/**
 * Application
 */
import React, { FunctionComponent, Fragment, useState, useCallback, useRef } from 'react';
import {
    BryntumDemoHeader,
    BryntumThemeCombo,
    BryntumGrid,
    BryntumButton,
    BryntumNumberField
} from '@bryntum/grid-react';
import { Grid, Toast, Model, Store, StringHelper, StateProvider } from '@bryntum/grid';

import { useGridConfig, rowHeightConfig } from './AppConfig';
import './App.scss';

const App: FunctionComponent = () => {
    StateProvider.setup('local');
    const gridRef = useRef<BryntumGrid>(null);
    const gridInstance = () => gridRef.current?.instance as Grid;

    const [rowHeight, setRowHeight] = useState(50);
    const [selectedRow, setSelectedRow] = useState<Model | null>(null);

    const handleAddRow = useCallback(() => {
        const grid = gridInstance();
        const store = grid.store as Store;
        store.add({
            team     : 'New team',
            division : '?'
        });
    }, []);

    const handleRemoveRow = useCallback(() => {
        selectedRow?.remove?.();
    }, [selectedRow]);

    const handleSelectionChange = useCallback(({ selected, mode }) => {
        if (mode === 'row') {
            setSelectedRow(selected.length ? selected[0] : null);
        }
    }, []);

    const getTeam = useCallback(() => {
        return selectedRow?.get('team') ?? 'None';
    }, [selectedRow]);

    const handleCellButtonClick = useCallback((record: Model) => {
        Toast.show(`Go ${StringHelper.encodeHtml(record.get('team'))}!`);
    }, []);

    const [gridConfig] = useState(useGridConfig(handleCellButtonClick));

    return (
        <Fragment>
            {/* BryntumDemoHeader component is used for Bryntum example styling only and can be removed */}
            <BryntumDemoHeader
                children = {<BryntumThemeCombo />}
            />
            <div className = "demo-toolbar align-right">
                <BryntumNumberField
                    {...rowHeightConfig}
                    value = {rowHeight}
                    onChange = {({ value }: { value: number }) =>
                        setRowHeight(value)
                    }
                />
                <div className = "spacer"></div>
                <label className = "selected-row">
                    Selected team: <span>{StringHelper.encodeHtml(getTeam())}</span>
                </label>
                <BryntumButton
                    cls = "b-green b-raised"
                    icon = "b-fa-plus"
                    tooltip = "Add Team"
                    onClick = {handleAddRow}
                />
                <BryntumButton
                    cls = "b-red b-raised"
                    icon = "b-fa-trash"
                    tooltip = "Remove Team"
                    disabled = {!selectedRow}
                    onClick = {handleRemoveRow}
                />
            </div>
            <BryntumGrid
                ref = {gridRef}
                {...gridConfig}
                rowHeight = {rowHeight}
                onSelectionChange = {handleSelectionChange}
            />
        </Fragment>
    );
};

export default App;
